@@ -68,17 +68,13 @@ bool operator>=(const Artist& lhs, const Artist& rhs);
 
 
 
-namespace std {
-
 template<>
-class hash<domain::Artist> {
+class std::hash<domain::Artist> {
 
 public:
     size_t operator()(const domain::Artist& artist) const;
 };
 
-}
-
 
 
 #endif // ARTIST_H
