@@ -3,7 +3,7 @@
 // Project: Ampache Browser
 // License: GNU GPLv3
 //
-// Copyright (C) 2015 - 2016 Róbert Čerňanský
+// Copyright (C) 2015 - 2024 Róbert Čerňanský
 
 
 
@@ -11,7 +11,8 @@
 #include "application/application.h"
 #include "application/application_qt_internal.h"
 
-using namespace std;
+class QWidget;
+
 using namespace ampache_browser;
 
 
