@@ -3,25 +3,29 @@
 // Project: Ampache Browser
 // License: GNU GPLv3
 //
-// Copyright (C) 2015 - 2016 Róbert Čerňanský
+// Copyright (C) 2015 - 2024 Róbert Čerňanský
 
 
 
 #include <memory>
 #include <functional>
-#include <QWidget>
+
 #include "application/application_qt_internal.h"
-#include "ampache_browser/settings.h"
-#include "ampache_browser/ampache_browser.h"
 #include "ampache_browser/application_qt.h"
 
-using namespace std;
+class QtWidget;
+
 using namespace application;
 
 
 
 namespace ampache_browser {
 
+class AmpacheBrowser;
+class Settings;
+
+
+
 ApplicationQt::ApplicationQt(): myApplicationQtInternal(new ApplicationQtInternal{}) {
 }
 
@@ -62,7 +66,7 @@ void ApplicationQt::run() {
 
 
 
-void ApplicationQt::finishRequest(function<void()> finishedCb) {
+void ApplicationQt::finishRequest(std::function<void()> finishedCb) {
     myApplicationQtInternal->finishRequest(finishedCb);
 }
 
