@@ -3,20 +3,23 @@
 // Project: Ampache Browser
 // License: GNU GPLv3
 //
-// Copyright (C) 2015 Róbert Čerňanský
+// Copyright (C) 2015 - 2024 Róbert Čerňanský
 
 
 
+#include <cctype>
+#include <algorithm>
+#include <string>
+
 #include "../data_objects/artist_data.h"
+#include "data/filters/filter.h"
 #include "data/filters/name_filter_for_artists.h"
 
-using namespace std;
-
 
 
 namespace data {
 
-NameFilterForArtists::NameFilterForArtists(const string& namePattern):
+NameFilterForArtists::NameFilterForArtists(const std::string& namePattern):
 myNamePattern(namePattern) {
 }
 
