@@ -3,28 +3,27 @@
 // Project: Ampache Browser
 // License: GNU GPLv3
 //
-// Copyright (C) 2015 - 2016 Róbert Čerňanský
+// Copyright (C) 2015 - 2024 Róbert Čerňanský
 
 
 
-#include <QObject>
+#include <Qt>
 #include <QImage>
 
 #include "scale_album_art_runnable.h"
 
-using namespace std;
-
 
 
 namespace data {
 
-ScaleAlbumArtRunnable::ScaleAlbumArtRunnable(const string id, const QByteArray imageData):
+ScaleAlbumArtRunnable::ScaleAlbumArtRunnable(const std::string id, const QByteArray imageData, int size):
 myId{id},
-myImageData{imageData} { }
+myImageData{imageData},
+mySize{size} { }
 
 
 
-string ScaleAlbumArtRunnable::getId() const {
+std::string ScaleAlbumArtRunnable::getId() const {
     return myId;
 }
 
@@ -39,8 +38,7 @@ QImage ScaleAlbumArtRunnable::getResult() const {
 void ScaleAlbumArtRunnable::run() {
     QImage art{};
     art.loadFromData(myImageData);
-    // SMELL: Image size is specified here.
-    myScaledAlbumArt = art.scaled(100, 100, Qt::AspectRatioMode::IgnoreAspectRatio,
+    myScaledAlbumArt = art.scaled(mySize, mySize, Qt::AspectRatioMode::IgnoreAspectRatio,
         Qt::TransformationMode::SmoothTransformation);
     emit finished(this);
 }
