@@ -3,7 +3,7 @@
 // Project: Ampache Browser
 // License: GNU GPLv3
 //
-// Copyright (C) 2015 - 2016 Róbert Čerňanský
+// Copyright (C) 2015 - 2024 Róbert Čerňanský
 
 
 
@@ -14,6 +14,7 @@
 
 #include <string>
 
+#include <QByteArray>
 #include <QObject>
 #include <QRunnable>
 #include <QImage>
@@ -22,12 +23,6 @@
 
 namespace data {
 
-class AlbumData;
-class ArtistData;
-class TrackData;
-
-
-
 /**
  * @brief Scales the given image to a predefined size.
  *
@@ -45,8 +40,9 @@ public:
      *
      * @param id Identifier of the scaled image.
      * @param imageData The image which shall be scaled.
+     * @param size Number of pixels the image shall be scaled to.
      */
-    explicit ScaleAlbumArtRunnable(const std::string id, const QByteArray imageData);
+    explicit ScaleAlbumArtRunnable(const std::string id, const QByteArray imageData, int size);
 
     /**
      * @brief Gets the identifier of the scaled image (which was passed to the constructor).
@@ -66,6 +62,7 @@ private:
     // arguments from the constructor
     const std::string myId;
     const QByteArray myImageData;
+    const int mySize = 0;
 
     // scaled image
     QImage myScaledAlbumArt;
