@@ -3,34 +3,33 @@
 // Project: Ampache Browser
 // License: GNU GPLv3
 //
-// Copyright (C) 2015 - 2016 Róbert Čerňanský
+// Copyright (C) 2015 - 2024 Róbert Čerňanský
 
 
 
+#include <cstddef>
 #include <string>
-#include <functional>
-#include "domain/artist.h"
 
-using namespace std;
+#include "domain/artist.h"
 
 
 
 namespace domain {
 
-Artist::Artist(const string& id, const string& name):
+Artist::Artist(const std::string& id, const std::string& name):
 myId{id},
 myName{name} {
 }
 
 
 
-const string Artist::getId() const {
+const std::string Artist::getId() const {
     return myId;
 }
 
 
 
-const string Artist::getName() const {
+const std::string Artist::getName() const {
     return myName;
 }
 
@@ -74,10 +73,6 @@ bool operator>=(const Artist& lhs, const Artist& rhs) {
 
 
 
-namespace std {
-
-size_t hash<domain::Artist>::operator()(const domain::Artist& artist) const {
-    return hash<string>()(artist.getId());
-}
-
+size_t std::hash<domain::Artist>::operator()(const domain::Artist& artist) const {
+    return std::hash<string>()(artist.getId());
 }
