@@ -3,7 +3,7 @@
 // Project: Ampache Browser
 // License: GNU GPLv3
 //
-// Copyright (C) 2015 - 2016 Róbert Čerňanský
+// Copyright (C) 2015 - 2024 Róbert Čerňanský
 
 
 
@@ -12,12 +12,14 @@
 
 
 
+#include <QObject>
 #include <QMainWindow>
 
 class QListView;
 class QTreeView;
 class QLineEdit;
 class QAction;
+class QWidget;
 
 
 
@@ -35,12 +37,12 @@ class AmpacheBrowserMainWindow: public QMainWindow {
    Q_OBJECT
 
 public:
+    static constexpr int ALBUM_THUMBNAIL_SIZE = 100;
+
     explicit AmpacheBrowserMainWindow(QWidget* parent = 0);
 
     ~AmpacheBrowserMainWindow();
 
-    CustomProxyStyle* myCustomProxyStyle = nullptr;
-
     QListView* albumsListView = nullptr;
     QListView* artistsListView = nullptr;
     QTreeView* tracksTreeView = nullptr;
@@ -51,6 +53,16 @@ public:
     QAction* addToPlaylistAction = nullptr;
 
     SettingsDialog* settingsDialog = nullptr;
+
+private:
+    CustomProxyStyle* myCustomProxyStyle = nullptr;
+
+    QSize sizeHint() const override;
+    
+    void createAndSetupToolBar();
+    void createAndSetupAlbumsWidget();
+    void createAndSetupArtistsWidget();
+    void createAndSetupTracksWidget();
 };
 
 }
