@@ -3,12 +3,18 @@
 // Project: Ampache Browser
 // License: GNU GPLv3
 //
-// Copyright (C) 2015 - 2017 Róbert Čerňanský
+// Copyright (C) 2015 - 2024 Róbert Čerňanský
 
 
 
+#include <QStyle>
+
 #include "custom_proxy_style.h"
 
+class QStyleHintReturn;
+class QStyleOption;
+class QWidget;
+
 
 
 namespace ui {
